@@ -91,14 +91,14 @@ class ZWaveMe:
                             if device["deviceType"] in self.zwaveplatforms
                         ]
                         for device in self._devices:
-                            _LOGGER.debug("CREATING DEVICE: %s", device)
+                            self._logger.debug("CREATING DEVICE: %s", device)
                         if not self._configured:
                             self._hass.config_entries.async_setup_platforms(
                                 self._config, self.platforms
                             )
                             self._configured = True
                 elif dict_data["type"] == "me.z-wave.devices.level":
-                    _LOGGER.debug("NEW DEVICE LEVEL: %s", self._devices)
+                    self._logger.debug("NEW DEVICE LEVEL: %s", self._devices)
                     for device in self._devices:
                         if device["id"] == dict_data["data"]["id"]:
                             device["visibility"] = dict_data["data"]["visibility"]
@@ -144,4 +144,4 @@ class ZWaveMe:
         return self._wshost
 
     async def async_update(self):
-        devices = self.update_devices()
\ No newline at end of file
+        devices = self.update_devices()
